@@ -1,4 +1,4 @@
-__version__ = '0.0.4'
+__version__ = '0.0.6'
 
 import evaics.sdk as sdk
 from types import SimpleNamespace
@@ -181,6 +181,7 @@ class LegacyNode:
         self.need_reload.set()
 
     def start(self):
+        logger.info(f'legacy v3 replication for the node {self.id} active')
         threading.Thread(target=self._t_reloader, daemon=True).start()
         threading.Thread(target=self._t_reload_scheduler, daemon=True).start()
 
@@ -540,7 +541,7 @@ def run():
     pubsub = psrt.Client(**pubsub_cfg)
     pubsub.on_message = process_message
     pubsub.connect()
-    test_topic = f'v4/tests/{service.system_name}/{service.name}/test'
+    test_topic = f'v4/tests/{service.system_name}/{service.id}/test'
     pubsub.subscribe(test_topic)
     _d.pubsub = pubsub
     _d.test_topic = test_topic
@@ -550,11 +551,12 @@ def run():
     pubsub.subscribe('controller/discovery')
     _d.bulks = [f'state/{t}' for t in pubsub_cfg.get('bulk_subscribe', [])]
     pubsub.subscribe_bulk(_d.bulks)
+    service.register_signals()
+    service.mark_ready()
+    logger.info('legacy replication service started')
+    service.wait_core()
     for _, c in _d.lc.items():
         c.start()
-    logger.info('legacy replication service started')
-    service.mark_ready()
-    service.register_signals()
     threading.Thread(target=watch_pubsub, daemon=True).start()
     threading.Thread(target=ping_pubsub, args=(test_topic,),
                      daemon=True).start()
